@@ -44,12 +44,12 @@ RecentAddressWidget::RecentAddressWidget(QWidget *parent)
     mLineEdit->installEventFilter(this);
     mLineEdit->setClearButtonEnabled(true);
     mLineEdit->setValidator(new KEmailValidator(this));
-    mLineEdit->setPlaceholderText(i18n("New email..."));
+    mLineEdit->setPlaceholderText(i18nc("@info:placeholder", "New email..."));
     connect(mLineEdit, &QLineEdit::returnPressed, this, &RecentAddressWidget::slotAddItem);
 
     lineLayout->addWidget(mLineEdit);
 
-    mNewButton->setToolTip(i18n("Add Email"));
+    mNewButton->setToolTip(i18nc("@info:tooltip", "Add Email"));
     mNewButton->setObjectName("new_button"_L1);
     mNewButton->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     mNewButton->setEnabled(false);
@@ -58,7 +58,7 @@ RecentAddressWidget::RecentAddressWidget(QWidget *parent)
     lineLayout->addWidget(mNewButton);
 
     mRemoveButton->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
-    mRemoveButton->setToolTip(i18n("Remove"));
+    mRemoveButton->setToolTip(i18nc("@info:tooltip", "Remove"));
     mRemoveButton->setObjectName("remove_button"_L1);
     mRemoveButton->setEnabled(false);
     lineLayout->addWidget(mRemoveButton);
